@@ -1,9 +1,9 @@
 package Music::ScaleNote;
 our $AUTHORITY = 'cpan:GENE';
 
-# ABSTRACT: Position of notes in a scale
+# ABSTRACT: Manipulate the position of notes in a scale
 
-our $VERSION = '0.0102';
+our $VERSION = '0.0103';
 
 use Carp;
 use Moo;
@@ -22,7 +22,8 @@ has scale_note => (
 
 
 has scale_name => (
-    is => 'ro',
+    is      => 'ro',
+    default => sub { 'major' },
 );
 
 
@@ -76,11 +77,11 @@ __END__
 
 =head1 NAME
 
-Music::ScaleNote - Position of notes in a scale
+Music::ScaleNote - Manipulate the position of notes in a scale
 
 =head1 VERSION
 
-version 0.0102
+version 0.0103
 
 =head1 SYNOPSIS
 
